@@ -1,11 +1,11 @@
-use 5.008001;
+use 5.006002;
 use strict;
 use warnings;
 
 package Test::TempDir::Tiny;
 # ABSTRACT: Temporary directories that stick around when tests fail
 
-our $VERSION = '0.013'; # TRIAL
+our $VERSION = '0.015'; # TRIAL
 
 use Exporter 5.57 qw/import/;
 our @EXPORT = qw/tempdir in_tempdir/;
@@ -213,8 +213,14 @@ END {
     # only clean up in original process, not children
     if ( $$ == $ORIGINAL_PID ) {
         # our clean up must run after Test::More sets $? in its END block
-        require B;
-        push @{ B::end_av()->object_2svref }, \&_cleanup;
+        if ( $] lt "5.008000" ) {
+            *Test::TempDir::Tiny::_CLEANER::DESTROY = \&_cleanup;
+            *blob = bless( {}, 'Test::TempDir::Tiny::_CLEANER' );
+        }
+        else {
+            require B;
+            push @{ B::end_av()->object_2svref }, \&_cleanup;
+        }
     }
 }
 
@@ -235,7 +241,7 @@ Test::TempDir::Tiny - Temporary directories that stick around when tests fail
 
 =head1 VERSION
 
-version 0.013
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -398,7 +404,7 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Christian Walde David Golden Shawn Laffan
+=for stopwords Christian Walde David Golden Kent Fredric Shawn Laffan
 
 =over 4
 
@@ -412,6 +418,10 @@ David Golden <xdg@xdg.me>
 
 =item *
 
+Kent Fredric <kentfredric@gmail.com>
+
+=item *
+
 Shawn Laffan <shawnlaffan@gmail.com>
 
 =back
